# Instructions

#### This is our test project
#### Pleae install this package
```
pip install functions-by-cloudproject
```

#### You can alss install older packages
```
pip install functions-by-cloudproject==VERSION_NUMBER
```